==> TopdataTopFinderProSW6-v6.5.2.zip: TopdataTopFinderProSW6/src/Storefront/Page/Topfinder/TopfinderPageLoader.php <==
<?php declare(strict_types=1);

namespace Topdata\TopdataTopFinderProSW6\Storefront\Page\Topfinder;

use Shopware\Core\Content\Category\Exception\CategoryNotFoundException;
use Shopware\Core\Content\Product\SalesChannel\Search\ProductSearchGatewayInterface;
use Shopware\Core\Framework\DataAbstractionLayer\Exception\InconsistentCriteriaIdsException;
//use Shopware\Core\Framework\Routing\Exception\MissingRequestParameterException;
use Shopware\Core\System\SalesChannel\SalesChannelContext;
use Shopware\Storefront\Framework\Page\StorefrontSearchResult;
use Shopware\Storefront\Page\GenericPageLoader;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;
use Symfony\Component\HttpFoundation\Request;

class TopfinderPageLoader
{
    /**
     * @var GenericPageLoader
     */
    private $genericLoader;

    /**
     * @var ProductSearchGatewayInterface
     */
//    private $searchGateway;

    /**
     * @var EventDispatcherInterface
     */
    private $eventDispatcher;

    public function __construct(
        GenericPageLoader $genericLoader,
//        ProductSearchGatewayInterface $searchGateway,
        EventDispatcherInterface $eventDispatcher
    ) {
        $this->genericLoader = $genericLoader;
//        $this->searchGateway = $searchGateway;
        $this->eventDispatcher = $eventDispatcher;
    }

    /**
     * @throws CategoryNotFoundException
     * @throws InconsistentCriteriaIdsException
     */
    public function load(Request $request, SalesChannelContext $salesChannelContext): TopfinderPage
    {
        $page = $this->genericLoader->load($request, $salesChannelContext);
        $page = TopfinderPage::createFrom($page);

//        if (!$request->query->has('search')) {
//            throw new MissingRequestParameterException('search');
//        }

//        $result = $this->searchGateway->search($request, $salesChannelContext);
//
//        $page->setListing($result);
//        $page->setSearchResult(StorefrontSearchResult::createFrom($result));

//        $page->setSearchTerm(
//            (string) $request->query->get('search')
//        );

        $this->eventDispatcher->dispatch(
            new TopfinderPageLoadedEvent($page, $salesChannelContext, $request)
        );

        return $page;
    }
}

==> TopdataTopFinderProSW6-v7.0.4.zip: TopdataTopFinderProSW6/src/Storefront/Page/Topfinder/TopfinderPageLoader.php <==
<?php

declare(strict_types=1);

namespace Topdata\TopdataTopFinderProSW6\Storefront\Page\Topfinder;

use Shopware\Core\Content\Category\Exception\CategoryNotFoundException;
use Shopware\Core\Content\Product\SalesChannel\Search\ProductSearchGatewayInterface;
use Shopware\Core\Framework\DataAbstractionLayer\Exception\InconsistentCriteriaIdsException;
//use Shopware\Core\System\SalesChannel\SalesChannelContext;
use Shopware\Storefront\Framework\Page\StorefrontSearchResult;
use Shopware\Storefront\Page\GenericPageLoader;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;
use Symfony\Component\HttpFoundation\Request;

class TopfinderPageLoader
{
    /**
     * @var GenericPageLoader
     */
    private $genericLoader;

    /**
     * @var ProductSearchGatewayInterface
     */
    //    private $searchGateway;

    /**
     * @var EventDispatcherInterface
     */
    private $eventDispatcher;

    public function __construct(
        GenericPageLoader $genericLoader,
        //        ProductSearchGatewayInterface $searchGateway,
        EventDispatcherInterface $eventDispatcher
    ) {
        $this->genericLoader = $genericLoader;
        //        $this->searchGateway = $searchGateway;
        $this->eventDispatcher = $eventDispatcher;
    }

    /**
     * @throws CategoryNotFoundException
     * @throws InconsistentCriteriaIdsException
     */
    public function load(Request $request, SalesChannelContext $salesChannelContext): TopfinderPage
    {
        $page = $this->genericLoader->load($request, $salesChannelContext);
        $page = TopfinderPage::createFrom($page);

        //        if (!$request->query->has('search')) {
        //            throw new \Symfony\Component\HttpKernel\Exception\BadRequestHttpException('search');
        //        }

        //        $result = $this->searchGateway->search($request, $salesChannelContext);
        //
        //        $page->setListing($result);
        //        $page->setSearchResult(StorefrontSearchResult::createFrom($result));

        //        $page->setSearchTerm(
        //            (string) $request->query->get('search')
        //        );

        $this->eventDispatcher->dispatch(
            new TopfinderPageLoadedEvent($page, $salesChannelContext, $request)
        );

        return $page;
    }
}
